@@ -8,7 +8,7 @@ import * as dbg from 'debug';
 import * as machina from 'machina';
 import * as async from 'async';
 
-import { anHourFromNow, endpoint, errors, results, SharedAccessSignature, Message, callbackToPromise, tripleValueCallbackToPromise, Callback } from 'azure-iot-common';
+import { anHourFromNow, errors, results, SharedAccessSignature, Message, callbackToPromise, tripleValueCallbackToPromise, Callback, endpoint } from 'azure-iot-common';
 import { Amqp as Base, AmqpMessage, SenderLink, AmqpBaseTransportConfig } from 'azure-iot-amqp-base';
 import { translateError } from './amqp_service_errors.js';
 import { Client } from './client';
@@ -16,11 +16,9 @@ import { ServiceReceiver } from './service_receiver.js';
 import { ResultWithIncomingMessage, IncomingMessageCallback, createResultWithIncomingMessage } from './interfaces.js';
 import { AccessToken } from '@azure/core-http';
 
-const UnauthorizedError = errors.UnauthorizedError;
-const DeviceNotFoundError = errors.DeviceNotFoundError;
-const NotConnectedError = errors.NotConnectedError;
 const debug = dbg('azure-iothub:Amqp');
-// tslint:disable-next-line:no-var-requires
+
+// eslint-disable-next-line @typescript-eslint/no-var-requires
 const packageJson = require('../package.json');
 
 function handleResult(errorMessage: string, done: IncomingMessageCallback<any>): IncomingMessageCallback<any> {
@@ -36,7 +34,7 @@ function handleResult(errorMessage: string, done: IncomingMessageCallback<any>):
 }
 
 function getTranslatedError(err: Error, message: string): Error {
-  if (err instanceof UnauthorizedError || err instanceof NotConnectedError || err instanceof DeviceNotFoundError) {
+  if (err instanceof errors.UnauthorizedError || err instanceof errors.NotConnectedError || err instanceof errors.DeviceNotFoundError) {
     return err;
   }
   return translateError(message, err);
@@ -341,7 +339,7 @@ export class Amqp extends EventEmitter implements Client.Transport {
               (callback) => {
                 /*Codes_SRS_NODE_IOTHUB_SERVICE_AMQP_16_021: [The `disconnect` method shall detach the C2D messaging link if it is attached.]*/
                 if (this._c2dLink) {
-                  let tmpC2DLink = this._c2dLink;
+                  const tmpC2DLink = this._c2dLink;
                   this._c2dLink = undefined;
                   if (err) {
                     debug('force-detaching c2d links');
@@ -367,7 +365,7 @@ export class Amqp extends EventEmitter implements Client.Transport {
               (callback) => {
                 /*Codes_SRS_NODE_IOTHUB_SERVICE_AMQP_16_022: [The `disconnect` method shall detach the C2D feedback receiver link if it is attached.]*/
                 if (this._feedbackReceiver) {
-                  let tmpFeedbackReceiver = this._feedbackReceiver;
+                  const tmpFeedbackReceiver = this._feedbackReceiver;
                   this._feedbackReceiver = undefined;
 
                   if (err) {
@@ -395,7 +393,7 @@ export class Amqp extends EventEmitter implements Client.Transport {
               /*Codes_SRS_NODE_IOTHUB_SERVICE_AMQP_16_023: [The `disconnect` method shall detach the file notification receiver link if it is attached.]*/
               (callback) => {
                 if (this._fileNotificationReceiver) {
-                  let tmpFileNotificationReceiver = this._fileNotificationReceiver;
+                  const tmpFileNotificationReceiver = this._fileNotificationReceiver;
                   this._fileNotificationReceiver = undefined;
 
                   if (err) {
@@ -506,9 +504,11 @@ export class Amqp extends EventEmitter implements Client.Transport {
     return tripleValueCallbackToPromise((_callback) => {
       const deviceEndpoint = endpoint.deviceMessagePath(encodeURIComponent(deviceId));
       /*Codes_SRS_NODE_IOTHUB_SERVICE_AMQP_16_002: [The `send` method shall construct an AMQP request using the message passed in argument as the body of the message.]*/
-      let amqpMessage = AmqpMessage.fromMessage(message);
+      const amqpMessage = AmqpMessage.fromMessage(message);
       this._fsm.handle('send', amqpMessage, deviceEndpoint, handleResult('AMQP Transport: Could not send message', _callback));
-    }, (r, m) => { return createResultWithIncomingMessage(r, m); }, done);
+    }, (r, m) => {
+      return createResultWithIncomingMessage(r, m);
+    }, done);
   }
 
   /**
@@ -524,7 +524,9 @@ export class Amqp extends EventEmitter implements Client.Transport {
   getFeedbackReceiver(done?: IncomingMessageCallback<Client.ServiceReceiver>): Promise<ResultWithIncomingMessage<Client.ServiceReceiver>> | void {
     return tripleValueCallbackToPromise((_callback) => {
       this._fsm.handle('getFeedbackReceiver', handleResult('AMQP Transport: Could not get feedback receiver', _callback));
-    }, (r, m) => { return createResultWithIncomingMessage(r, m); }, done);
+    }, (r, m) => {
+      return createResultWithIncomingMessage(r, m);
+    }, done);
   }
 
   /**
@@ -540,7 +542,9 @@ export class Amqp extends EventEmitter implements Client.Transport {
   getFileNotificationReceiver(done?: IncomingMessageCallback<Client.ServiceReceiver>): Promise<ResultWithIncomingMessage<Client.ServiceReceiver>> | void {
     return tripleValueCallbackToPromise((_callback) => {
       this._fsm.handle('getFileNotificationReceiver', handleResult('AMQP Transport: Could not get file notification receiver', _callback));
-    }, (r, m) => { return createResultWithIncomingMessage(r, m); }, done);
+    }, (r, m) => {
+      return createResultWithIncomingMessage(r, m);
+    }, done);
   }
 
   /**
