@@ -16,7 +16,7 @@ import { Callback, tripleValueCallbackToPromise } from 'azure-iot-common';
 import { IncomingMessage } from 'http';
 import { TokenCredential } from '@azure/core-http';
 
-// tslint:disable-next-line:no-var-requires
+// eslint-disable-next-line @typescript-eslint/no-var-requires
 const packageJson = require('../package.json');
 
 const MAX_RETRY_TIMEOUT = 240000; // 4 minutes
@@ -91,7 +91,9 @@ export class Client extends EventEmitter {
             if (_callback) _callback(null, result);
           }
         });
-    }, (r, m) => { return createResultWithIncomingMessage(r, m); }, done);
+    }, (r, m) => {
+      return createResultWithIncomingMessage(r, m);
+    }, done);
   }
 
   /**
@@ -123,7 +125,9 @@ export class Client extends EventEmitter {
           if (_callback) _callback(null, result);
         }
       });
-    }, (r, m) => { return createResultWithIncomingMessage(r, m); }, done);
+    }, (r, m) => {
+      return createResultWithIncomingMessage(r, m);
+    }, done);
   }
 
   /**
@@ -186,7 +190,9 @@ export class Client extends EventEmitter {
           }
         }
       });
-    }, (r, m) => { return createResultWithIncomingMessage(r, m); }, done);
+    }, (r, m) => {
+      return createResultWithIncomingMessage(r, m);
+    }, done);
   }
 
   _invokeDeviceMethod(deviceId: string, moduleIdOrMethodParams: string | DeviceMethodParams, methodParamsOrDone?: DeviceMethodParams | IncomingMessageCallback<any>, done?: IncomingMessageCallback<any>): void {
@@ -277,11 +283,15 @@ export class Client extends EventEmitter {
     if (moduleId) {
       return tripleValueCallbackToPromise((_callback) => {
         this._invokeDeviceMethod(deviceId, moduleId, methodParams, _callback);
-      }, (r: any, m: IncomingMessage) => { return createResultWithIncomingMessage(r, m); }, callback);
+      }, (r: any, m: IncomingMessage) => {
+        return createResultWithIncomingMessage(r, m);
+      }, callback);
     } else {
       return tripleValueCallbackToPromise((_callback) => {
         this._invokeDeviceMethod(deviceId, methodParams, _callback);
-      }, (r: any, m: IncomingMessage) => { return createResultWithIncomingMessage(r, m); }, callback);
+      }, (r: any, m: IncomingMessage) => {
+        return createResultWithIncomingMessage(r, m);
+      }, callback);
     }
   }
 
@@ -320,7 +330,9 @@ export class Client extends EventEmitter {
           }
         }
       });
-    }, (r, m) => { return createResultWithIncomingMessage(r, m); }, done);
+    }, (r, m) => {
+      return createResultWithIncomingMessage(r, m);
+    }, done);
   }
 
   /**
@@ -352,7 +364,9 @@ export class Client extends EventEmitter {
           }
         }
       });
-    }, (r, m) => { return createResultWithIncomingMessage(r, m); }, done);
+    }, (r, m) => {
+      return createResultWithIncomingMessage(r, m);
+    }, done);
   }
 
   /**
@@ -383,7 +397,7 @@ export class Client extends EventEmitter {
 
   private _disconnectHandler(reason: string): void {
     /*Codes_SRS_NODE_IOTHUB_CLIENT_16_004: [** The `disconnect` event shall be emitted when the client is disconnected from the server.]*/
-    let evt = new results.Disconnected();
+    const evt = new results.Disconnected();
     evt.reason = reason;
     this.emit('disconnect', evt);
   }
@@ -495,6 +509,7 @@ export class Client extends EventEmitter {
   }
 }
 
+// eslint-disable-next-line no-redeclare
 export namespace Client {
   export interface TransportConfigOptions {
     /**
