@@ -9,8 +9,8 @@ import { TripleValueCallback } from 'azure-iot-common';
 export type IncomingMessageCallback<TResult> = TripleValueCallback<TResult, IncomingMessage>;
 
 export type ResultWithIncomingMessage<TResult> = {
-    result: TResult,
-    message: IncomingMessage
+    result: TResult;
+    message: IncomingMessage;
 };
 
 export function createResultWithIncomingMessage<TResult>(result: TResult, message: IncomingMessage): ResultWithIncomingMessage<TResult> {
