@@ -4,7 +4,6 @@
 'use strict';
 
 import { Agent } from 'https';
-import { endpoint } from 'azure-iot-common';
 import * as ConnectionString from './connection_string';
 import * as SharedAccessSignature from './shared_access_signature';
 import { RestApiClient } from 'azure-iot-http-base';
@@ -13,8 +12,10 @@ import { Query } from './query';
 import { DeviceMethodParams } from './interfaces';
 import { TripleValueCallback, tripleValueCallbackToPromise } from 'azure-iot-common';
 import { TokenCredential } from '@azure/core-http';
+import { versionQueryString } from './version';
 
-// tslint:disable-next-line:no-var-requires
+
+// eslint-disable-next-line @typescript-eslint/no-var-requires
 const packageJson = require('../package.json');
 
 const defaultMaxExecutionTimeInSeconds = 3600;
@@ -86,7 +87,7 @@ export class JobClient {
       Request-Id: <guid>
       User-Agent: <sdk-name>/<sdk-version>
       ```]*/
-      const path = '/jobs/v2/' + jobId + endpoint.versionQueryString();
+      const path = '/jobs/v2/' + jobId + versionQueryString();
       this._restApiClient.executeApiCall('GET', path, null, null, _callback);
     }, createJobStatusResponse, done);
   }
@@ -130,7 +131,7 @@ export class JobClient {
       Request-Id: <guid>
       User-Agent: <sdk-name>/<sdk-version>
       ```]*/
-      const path = '/jobs/v2/' + jobId + '/cancel' + endpoint.versionQueryString();
+      const path = '/jobs/v2/' + jobId + '/cancel' + versionQueryString();
       this._restApiClient.executeApiCall('POST', path, null, null, _callback);
     }, createJobStatusResponse, done);
   }
@@ -228,7 +229,7 @@ export class JobClient {
         maxExecutionTimeInSeconds: <maxExecutionTimeInSeconds>        // format TBD
       }
       ```]*/
-      let jobDesc: JobDescription = {
+      const jobDesc: JobDescription = {
         jobId: jobId,
         type: 'scheduleDeviceMethod',
         cloudToDeviceMethod: fullMethodParams,
@@ -302,7 +303,7 @@ export class JobClient {
         }
       }
 
-      let jobDesc: JobDescription = {
+      const jobDesc: JobDescription = {
         jobId: jobId,
         type: 'scheduleUpdateTwin',
         updateTwin: patch,
@@ -351,9 +352,9 @@ export class JobClient {
       ```]*/
       const jobStatusQueryParam = jobStatus ? '&jobStatus=' + encodeURIComponent(jobStatus) : '';
       const jobTypeQueryParam = jobType ? '&jobType=' + encodeURIComponent(jobType) : '';
-      const path = '/jobs/v2/query' + endpoint.versionQueryString() + jobStatusQueryParam + jobTypeQueryParam;
+      const path = '/jobs/v2/query' + versionQueryString() + jobStatusQueryParam + jobTypeQueryParam;
 
-      let headers = {};
+      const headers = {};
       if (continuationToken) {
         headers['x-ms-continuation'] = continuationToken;
       }
@@ -367,7 +368,7 @@ export class JobClient {
   }
 
   private _scheduleJob(jobDesc: JobDescription, done: TripleValueCallback<any, any>): void {
-    const path = '/jobs/v2/' + encodeURIComponent(jobDesc.jobId.toString()) + endpoint.versionQueryString();
+    const path = '/jobs/v2/' + encodeURIComponent(jobDesc.jobId.toString()) + versionQueryString();
     const headers = {
       'Content-Type': 'application/json; charset=utf-8'
     };
@@ -455,6 +456,7 @@ export class JobClient {
   }
 }
 
+// eslint-disable-next-line no-redeclare
 export namespace JobClient {
   export type JobCallback = TripleValueCallback<any, any>; // (err: Error, jobStatus?: any, response?: any) => void;
 }
